summaryrefslogtreecommitdiffstats
path: root/chrome/browser/automation/automation_provider.h
diff options
context:
space:
mode:
Diffstat (limited to 'chrome/browser/automation/automation_provider.h')
-rw-r--r--chrome/browser/automation/automation_provider.h10
1 files changed, 3 insertions, 7 deletions
diff --git a/chrome/browser/automation/automation_provider.h b/chrome/browser/automation/automation_provider.h
index a0d2dd7..524fd62 100644
--- a/chrome/browser/automation/automation_provider.h
+++ b/chrome/browser/automation/automation_provider.h
@@ -476,11 +476,11 @@ class AutomationProvider : public base::RefCounted<AutomationProvider>,
// data structure used in the browser.
// Args:
// profiles/cards: the ListValue of profiles/credit cards to translate.
// json_return: a pointer to the return string in case of error.
static std::vector<AutoFillProfile> GetAutoFillProfilesFromList(
- const ListValue& profiles, std::string* json_return);
+ const ListValue& profiles, std::string* error_message);
static std::vector<CreditCard> GetCreditCardsFromList(
- const ListValue& cards, std::string* json_return);
+ const ListValue& cards, std::string* error_message);
// The opposite of the above: translates from the internal data structure
// for profiles and credit cards to a ListValue of DictionaryValues. The
@@ -497,10 +497,6 @@ class AutomationProvider : public base::RefCounted<AutomationProvider>,
static std::map<AutoFillFieldType, std::wstring>
GetCreditCardFieldToStringMap();
- // Util for creating a JSON error return string (dict with key
- // 'error' and error string value). No need to quote input.
- static std::string JSONErrorString(const std::string& err);
-
// Generic pattern for pyautolib
// Uses the JSON interface for input/output.
void SendJSONRequest(int handle,
@@ -476,11 +476,11 @@ class AutomationProvider : public base::RefCounted<AutomationProvider>,
// Args:
// profiles/cards: the ListValue of profiles/credit cards to translate.
- // json_return: a pointer to the return string in case of error.
+ // error_message: a pointer to the return string in case of error.
static std::vector<AutoFillProfile> GetAutoFillProfilesFromList(